summaryrefslogtreecommitdiff
path: root/w32/compat
diff options
context:
space:
mode:
authorPaul Smith <psmith@gnu.org>1997-04-07 07:21:16 +0000
committerPaul Smith <psmith@gnu.org>1997-04-07 07:21:16 +0000
commit0ada207e2dca2b69a65ce186e625e7f6397edd34 (patch)
treedc117c22dc40a3d94b4ba2c5acc71ac8e53582a9 /w32/compat
parent7bb7ba784904b414b1f5f604414d232871f77a69 (diff)
downloadgunmake-0ada207e2dca2b69a65ce186e625e7f6397edd34.tar.gz
Changes for make 3.75.1
Diffstat (limited to 'w32/compat')
-rw-r--r--w32/compat/dirent.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/w32/compat/dirent.c b/w32/compat/dirent.c
index 25a7b74..9416828 100644
--- a/w32/compat/dirent.c
+++ b/w32/compat/dirent.c
@@ -78,7 +78,7 @@ closedir(DIR *pDir)
return;
}
/* close the WIN32 directory handle */
if (pDir->dir_hDirHandle != INVALID_HANDLE_VALUE)
FindClose(pDir->dir_hDirHandle);
@@ -90,7 +90,7 @@ closedir(DIR *pDir)
struct dirent *
readdir(DIR* pDir)
{
- WIN32_FIND_DATA wfdFindData;
+ WINDOWS32_FIND_DATA wfdFindData;
if (!pDir) {
errno = EINVAL;
@@ -134,7 +134,7 @@ rewinddir(DIR* pDir)
return;
}
/* close the WIN32 directory handle */
if (pDir->dir_hDirHandle != INVALID_HANDLE_VALUE)
if (!FindClose(pDir->dir_hDirHandle))
errno = EBADF;
@@ -78,7 +78,7 @@ closedir(DIR *pDir)
return;
}
- /* close the WIN32 directory handle */
+ /* close the WINDOWS32 directory handle */
if (pDir->dir_hDirHandle != INVALID_HANDLE_VALUE)
FindClose(pDir->dir_hDirHandle);
@@ -134,7 +134,7 @@ rewinddir(DIR* pDir)
return;
}
- /* close the WIN32 directory handle */
+ /* close the WINDOWS32 directory handle */
if (pDir->dir_hDirHandle != INVALID_HANDLE_VALUE)
if (!FindClose(pDir->dir_hDirHandle))